==> vue-connect-ui-0.9.0.tgz: package/src/components/input/input.rules.js <==
import { StyleSheet } from 'fela-tools'
import { COLOR, EDGES, ICON } from '../../core/constants'
import { offset } from '../../core/utils'
import edges from '../../rules/edges/edges'
import text from '../../rules/text/text'

const HEIGHT = 32

export default StyleSheet.create({
  input: {
    position: 'relative',
    paddingTop: HEIGHT
  },
  label: ({ dirty, invalid, hasErrors }) => ({
    userSelect: 'none',
    position: 'absolute',
    top: 10,
    left: 0,
    extend: [
      text({
        color: hasErrors || (dirty && invalid)
          ? COLOR.CLAY
          : COLOR.SLATE
      })
    ]
  }),
  field: ({ dirty, invalid, hasErrors }) => ({
    display: 'block',
    boxSizing: 'border-box',
    outline: 'none',
    width: '100%',
    height: HEIGHT,
    border: {
      color: hasErrors
        ? COLOR.CLAY
        : dirty
          ? invalid
            ? COLOR.CLAY
            : COLOR.LEAF
          : COLOR.STONE
    },
    placeholder: {
      color: COLOR.PLACEHOLDER
    },
    extend: [
      text(),
      edges({
        value: 8,
        edges: EDGES.LR,
        prefix: 'padding'
      })
    ],
    onFocus: {
      border: {
        color: dirty
          ? invalid
            ? COLOR.CLAY
            : COLOR.LEAF
          : COLOR.BLUE
      }
    }
  }),
  icon: ({ dirty, hasErrors }) => ({
    padding: offset(HEIGHT, ICON.SMALL),
    visibility: dirty || hasErrors ? 'visible' : 'hidden',
    position: 'absolute',
    left: '100%',
    top: HEIGHT
  }),
  error: {
    marginTop: 4
  }
})

==> vue-connect-ui-0.10.0.tgz: package/src/components/input/input.rules.js <==
import { StyleSheet } from 'fela-tools'
import { COLOR, EDGES, ICON } from '../../core/constants'
import { offset } from '../../core/utils'
import edges from '../../rules/edges/edges'
import text from '../../rules/text/text'

const HEIGHT = 32

export default StyleSheet.create({
  input: {
    position: 'relative',
    paddingTop: HEIGHT
  },
  label: ({ isInvalid }) => ({
    userSelect: 'none',
    position: 'absolute',
    top: 10,
    left: 0,
    extend: [
      text({
        color: isInvalid
          ? COLOR.CLAY
          : COLOR.SLATE
      })
    ]
  }),
  field: ({ dirty, invalid, isInvalid }) => ({
    display: 'block',
    boxSizing: 'border-box',
    outline: 'none',
    width: '100%',
    height: HEIGHT,
    border: {
      color: isInvalid
        ? COLOR.CLAY
        : dirty
          ? invalid
            ? COLOR.CLAY
            : COLOR.LEAF
          : COLOR.STONE
    },
    placeholder: {
      color: COLOR.PLACEHOLDER
    },
    extend: [
      text(),
      edges({
        value: 8,
        edges: EDGES.LR,
        prefix: 'padding'
      })
    ],
    onFocus: {
      border: {
        color: isInvalid
          ? COLOR.CLAY
          : dirty
            ? invalid
              ? COLOR.CLAY
              : COLOR.LEAF
            : COLOR.BLUE
      }
    }
  }),
  icon: ({ dirty, isInvalid }) => ({
    padding: offset(HEIGHT, ICON.SMALL),
    visibility: dirty || isInvalid ? 'visible' : 'hidden',
    position: 'absolute',
    left: '100%',
    top: HEIGHT
  }),
  errors: {
    paddingTop: 4
  }
})
